﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Data;
using System.Xml;

namespace Prova4
{
    static class DataSetBuilder
    {
        public static DataSet Build(string fileName)
        {
            if (String.IsNullOrEmpty(fileName))
                throw new ArgumentException("String.IsNullOrEmpty(fileName)");
            XmlDocument xmlDocument = new XmlDocument();
            xmlDocument.Load(fileName);
            DataSet dataSet = new DataSet();
            foreach (XmlElement tableElement in xmlDocument.SelectNodes("/Schema/Table"))
            {
                DataTable table = CreateTable(tableElement);
                dataSet.Tables.Add(table);
            }
            foreach (XmlElement tableElement in xmlDocument.SelectNodes("/Schema/Table"))
            {
                DataTable childTable = dataSet.Tables[tableElement.GetAttribute("name")];
                foreach (XmlElement columnElement in tableElement.SelectNodes("Column[@parentTable]"))
                {
                    DataColumn childColumn = childTable.Columns[columnElement.GetAttribute("name")];
                    DataTable parentTable = dataSet.Tables[columnElement.GetAttribute("parentTable")];
                    if (parentTable == null)
                        throw new ApplicationException("parentTable == null");
                    dataSet.Relations.Add(parentTable.PrimaryKey[0], childColumn);
                }
            }
            return dataSet;
        }

        private static DataTable CreateTable(XmlElement tableElement)
        {
            if (!tableElement.HasAttribute("name"))
                throw new ApplicationException("!tableElement.HasAttribute(\"name\")");
            DataTable table = new DataTable(tableElement.GetAttribute("name"));
            foreach (XmlElement columnElement in tableElement.SelectNodes("Column"))
            {
                if (!columnElement.HasAttribute("name"))
                    throw new ApplicationException("!columnElement.HasAttribute(\"name\")");
                if (!columnElement.HasAttribute("type"))
                    throw new ApplicationException("!columnElement.HasAttribute(\"type\")");
                DataColumn dataColumn = new DataColumn(columnElement.GetAttribute("name"));
                dataColumn.DataType = Type.GetType(columnElement.GetAttribute("type"), true);
                table.Columns.Add(dataColumn);
                if (columnElement.HasAttribute("primaryKey"))
                {
                    if (XmlConvert.ToBoolean(columnElement.GetAttribute("primaryKey")))
                    {
                        if (table.PrimaryKey.Length > 0)
                            throw new ApplicationException("table.PrimaryKey.Length > 0");
                        table.PrimaryKey = new DataColumn[] { dataColumn };
                    }
                }
            }
            if (table.PrimaryKey.Length == 0)
                throw new ApplicationException("table.PrimaryKey.Length == 0");
            return table;
        }
    }
}
