﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Data;
using System.Xml;

namespace Prova4
{
    static class DataSetLoader
    {
        public static void LoadData(DataSet dataSet, string fileName)
        {
            if (dataSet == null)
                throw new ArgumentNullException("dataSet");
            if (dataSet.Tables.Count == 0)
                throw new ArgumentException("dataSet.Tables.Count == 0");
            if (String.IsNullOrEmpty(fileName))
                throw new ArgumentException("String.IsNullOrEmpty(fileName)");
            XmlDocument xmlDocument = new XmlDocument();
            xmlDocument.Load(fileName);
            dataSet.EnforceConstraints = false;
            foreach (XmlElement tableElement in xmlDocument.SelectNodes("/Data/Table"))
            {
                if (!tableElement.HasAttribute("name"))
                    throw new ApplicationException("!tableElement.HasAttribute(\"name\")");
                DataTable table = dataSet.Tables[tableElement.GetAttribute("name")];
                if (table == null)
                    throw new ApplicationException("table == null");
                foreach (XmlElement rowElement in tableElement.SelectNodes("Row"))
                {
                    AddRow(table, rowElement);
                }
            }
            dataSet.EnforceConstraints = true;
        }

        private static void AddRow(DataTable table, XmlElement rowElement)
        {
            DataRow dataRow = table.NewRow();
            foreach (XmlElement columnElement in rowElement.SelectNodes("ColumnValue"))
            {
                DataColumn dataColumn = table.Columns[columnElement.GetAttribute("name")];
                if (dataColumn == null)
                    throw new ApplicationException("dataColumn == null");
                if (columnElement.HasAttribute("null") &&
                   XmlConvert.ToBoolean(columnElement.GetAttribute("null")))
                {
                    dataRow[dataColumn] = DBNull.Value;
                }
                else
                {
                    dataRow[dataColumn] = Convert.ChangeType(columnElement.InnerText, dataColumn.DataType);
                }
            }
            table.Rows.Add(dataRow);
        }
    }
}
