﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace Prova4
{
    public partial class DataSetNavigator : Form
    {
        private DataSet _dataSet;

        public DataSetNavigator()
        {
            InitializeComponent();
            Application.Idle += new EventHandler(Application_Idle);
        }

        private void Application_Idle(object sender, EventArgs e)
        {
            dataToolStripMenuItem.Enabled = (_dataSet != null && _dataSet.Tables.Count > 0);
        }

        private void schemaToolStripMenuItem_Click(object sender, EventArgs e)
        {
            using (OpenFileDialog openFileDialog = new OpenFileDialog())
            {
                openFileDialog.Title = "Select a schema file";
                openFileDialog.Filter = "XML Files|*.xml";
                openFileDialog.RestoreDirectory = true;
                if (openFileDialog.ShowDialog() == DialogResult.OK)
                {
                    _dataSet = DataSetBuilder.Build(openFileDialog.FileName);
                    OnDataSetSchemaChanged();
                }
            }
        }

        private void dataToolStripMenuItem_Click(object sender, EventArgs e)
        {
            using (OpenFileDialog openFileDialog = new OpenFileDialog())
            {
                openFileDialog.Title = "Select a data file";
                openFileDialog.Filter = "XML Files|*.xml";
                openFileDialog.RestoreDirectory = true;
                if (openFileDialog.ShowDialog() == DialogResult.OK)
                {
                    DataSetLoader.LoadData(_dataSet, openFileDialog.FileName);
                }
            }
        }

        private void OnDataSetSchemaChanged()
        {
            _tabControl.TabPages.Clear();
            foreach (DataTable table in _dataSet.Tables)
            {
                TabPage tabPage = CreateTabPage(table);
                _tabControl.TabPages.Add(tabPage);
            }
        }

        private static TabPage CreateTabPage(DataTable table)
        {
            TabPage tabPage = new TabPage(table.TableName);
            DataGridView dataGridView = new DataGridView();
            dataGridView.ReadOnly = true;
            dataGridView.AllowUserToAddRows = false;
            dataGridView.AllowUserToDeleteRows = false;
            dataGridView.ColumnHeadersHeightSizeMode = System.Windows.Forms.DataGridViewColumnHeadersHeightSizeMode.AutoSize;
            dataGridView.Dock = System.Windows.Forms.DockStyle.Fill;
            dataGridView.DataSource = table;
            tabPage.Controls.Add(dataGridView);
            tabPage.Padding = new System.Windows.Forms.Padding(3);
            tabPage.UseVisualStyleBackColor = true;
            return tabPage;
        }
    }
}
